// *******************************************************************
//  admin/phpLinks2.sql
// *******************************************************************

// Last Updated July 22, 2001  (2.1)

create table sessions (
   id varchar(32) not null,
   data text not null,
   expire int(11) unsigned default '0' not null,
   primary key (id)
);

create table categories (
   ID smallint(5) unsigned not null auto_increment,
   Category varchar(32) not null,
   PID smallint(5) unsigned default '0' not null,
   Children enum('Top','Rand','Desc') default 'Top' not null,
   TopChildren tinyint(3) unsigned default '3' not null,
   AllowSites enum('Y','N') default 'Y' not null,
   ShowSiteCount enum('Y','N') default 'Y' not null,
   Description text not null,
   primary key (ID),
   key Category (Category),
   key TopChildren (TopChildren),
   key Children (Children),
   key PID (PID)
);

create table links (
   ID int(7) unsigned not null auto_increment,
   SiteName varchar(100) not null,
   SiteURL varchar(100) not null,
   LastUpdate timestamp(14),
   Added varchar(14),
   Description blob not null,
   Category smallint(6) unsigned default '0' not null,
   Country varchar(100) default 'United_States.gif' not null,
   UserName varchar(16) not null,
   Password varchar(16) not null,
   Hint varchar(50) not null,
   Email varchar(50) not null,
   InIP varchar(15) not null,
   OutIP varchar(15) not null,
   HitsIn int(7) unsigned default '0' not null,
   HitsOut int(7) unsigned default '0' not null,
   primary key (ID),
   unique SiteURL (SiteURL),
   key Category (Category)
);

create table related (
   ID int(10) not null auto_increment,
   Category tinyint(3) unsigned default '0' not null,
   R1 tinyint(3) unsigned default '0' not null,
   R2 tinyint(3) unsigned default '0' not null,
   R3 tinyint(3) unsigned default '0' not null,
   R4 tinyint(3) unsigned default '0' not null,
   R5 tinyint(3) unsigned default '0' not null,
   primary key (ID)
);

create table reviews (
   ID int(11) unsigned not null auto_increment,
   SiteID int(11) unsigned default '0' not null,
   ReviewTitle varchar(100) not null,
   Review text not null,
   Reviewer varchar(50) not null,
   ReviewerEmail varchar(50) not null,
   ReviewerURL varchar(100) not null,
   Rating tinyint(3) unsigned default '0' not null,
   Status enum('New','Show','Hide') default 'New' not null,
   Added timestamp(14),
   primary key (ID),
   key Rating (Rating)
);

create table settings (
   ID tinyint(4) unsigned not null auto_increment,
   SiteTitle varchar(50) default 'phpLinks' not null,
   Theme varchar(16) default 'original' not null,
   Language varchar(16) default 'english' not null,
   Name varchar(50) not null,
   Email varchar(50) not null,
   DateFormat varchar(16) default 'M j, Y' not null,
   defaultCountry varchar(50) default 'United States' not null,
   ColCount enum('2','3','4'),
   ManuallyValidate enum('Y','N') default 'Y' not null,
   URLValidate enum('Y','N') default 'Y' not null,
   NewSubmissionEmail enum('Y','N') default 'Y' not null,
   SiteAdditionEmail enum('Y','N') default 'Y' not null,
   SiteDeletionEmail enum('Y','N') default 'Y' not null,
   PerPage tinyint(3) default '10' not null,
   NavLinks tinyint(3) default '3' not null,
   BaseURL varchar(50) not null,
   BasePath varchar(50) not null,
   primary key (ID)
);

INSERT INTO settings (
	ID,
	SiteTitle,
	Theme,
	Language,
	Name,
	Email,
	DateFormat, 
	defaultCountry, 
	ColCount, 
	ManuallyValidate, 
	URLValidate, 
	NewSubmissionEmail, 
	SiteAdditionEmail, 
	SiteDeletionEmail, 
	PerPage, 
	NavLinks, 
	BaseURL, 
	BasePath
) VALUES ( 
	'1', 
	'phpLinks', 
	'original', 
	'english', 
	'Your Name', 
	'webmaster@yourdomain.com', 
	'M j, Y', 
	'United_States.gif', 
	'3', 
	'Y', 
	'N', 
	'Y', 
	'Y', 
	'Y', 
	'10', 
	'4', 
	'http://yourdomain.com/phplinks', 
	'/path/to/phplinks'
);

create table specs (
   ID tinyint(3) unsigned not null auto_increment,
   SiteNameMin tinyint(4) default '0' not null,
   SiteNameMax tinyint(4) default '0' not null,
   DescMin tinyint(4) default '0' not null,
   DescMax smallint(4) default '0' not null,
   UserNameMin tinyint(4) default '0' not null,
   UserNameMax tinyint(4) default '0' not null,
   PWMin tinyint(4) default '0' not null,
   PWMax tinyint(4) default '0' not null,
   HintMin tinyint(4) default '0' not null,
   HintMax tinyint(4) default '0' not null,
   EmailSpec varchar(255) default '^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-])+' not null,
   ReviewTitleMin tinyint(4) default '5' not null,
   ReviewTitleMax tinyint(4) default '120' not null,
   ReviewerMin tinyint(4) default '4' not null,
   ReviewerMax tinyint(4) default '50' not null,
   ReviewMin tinyint(4) default '50' not null,
   ReviewMax mediumint(9) default '1000' not null,
   ReviewerEmailSpec varchar(255) default '^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-])+' not null,
   primary key (ID)
);

INSERT INTO
	specs (
		ID,
		SiteNameMin,
		SiteNameMax,
		DescMin,
		DescMax,
		UserNameMin,
		UserNameMax,
		PWMin,
		PWMax,
		HintMin,
		HintMax,
		EmailSpec,
		ReviewTitleMin,
		ReviewTitleMax,
		ReviewerMin,
		ReviewerMax,
		ReviewMin,
		ReviewMax,
		ReviewerEmailSpec
) VALUES (
		'1',
		'5',
		'120',
		'32',
		'384',
		'8',
		'16',
		'8',
		'16',
		'5',
		'50',
		'^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-])+',
		'5',
		'120',
		'4',
		'50',
		'50',
		'1000',
		'^^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-])+'
);

create table temp (
   ID int(7) unsigned not null auto_increment,
   SiteName varchar(100) not null,
   SiteURL varchar(100) not null,
   LastUpdate timestamp(14),
   Added varchar(14),
   Description blob not null,
   Category smallint(6) unsigned default '0' not null,
   Country varchar(100) default 'United_States.gif' not null,
   UserName varchar(16) not null,
   Password varchar(16) not null,
   Hint varchar(50) not null,
   Email varchar(50) not null,
   HitsIn int(7) unsigned default '0' not null,
   HitsOut int(7) unsigned default '0' not null,
   InIP varchar(15) not null,
   OutIP varchar(15) not null,
   primary key (ID),
   unique SiteURL (SiteURL)
);

create table terms (
   ID int(10) unsigned not null auto_increment,
   Term varchar(50) not null,
   primary key (ID),
   key Term (Term)
);
